from __future__ import annotations
from typing import Any, Callable, Dict, List, Optional, Tuple
from msgpack._version import version
from msgpack import _version
from msgpack.exceptions import (
    BufferFull,
    ExtraData,
    FormatError,
    OutOfData,
    PackException,
    PackOverflowError,
    PackValueError,
    StackError,
    UnpackException,
    UnpackValueError,
)
from typing_extensions import Protocol
from msgpack.fallback import Packer, Unpacker, unpackb
from msgpack import exceptions
from msgpack.ext import ExtType, Timestamp
from msgpack import ext

class _Stream(Protocol):
    def read(self) -> bytes: ...

class _FileLike(Protocol):
    def read(n: int) -> bytes: ...

def pack(
    o: Any,
    stream: _Stream,
    default: Optional[Callable[[Any], Any]] = ...,
    use_single_float: bool = ...,
    autoreset: bool = ...,
    use_bin_type: bool = ...,
    strict_types: bool = ...,
    datetime: bool = ...,
    unicode_errors: Optional[str] = ...,
) -> None: ...
def packb(
    o: Any,
    default: Optional[Callable[[Any], Any]] = ...,
    use_single_float: bool = ...,
    autoreset: bool = ...,
    use_bin_type: bool = ...,
    strict_types: bool = ...,
    datetime: bool = ...,
    unicode_errors: Optional[str] = ...,
) -> bytes: ...
def unpack(
    stream: _Stream,
    file_like: Optional[_FileLike] = ...,
    read_size: int = ...,
    use_list: bool = ...,
    raw: bool = ...,
    timestamp: int = ...,
    strict_map_key: bool = ...,
    object_hook: Optional[Callable[[Dict[Any, Any]], Any]] = ...,
    object_pairs_hook: Optional[Callable[[List[Tuple[Any, Any]]], Any]] = ...,
    list_hook: Optional[[Callable[[List[Any]], Any]]] = ...,
    unicode_errors: Optional[str] = ...,
    max_buffer_size: int = ...,
    ext_hook: Callable[[int, bytes], Any] = ...,
    max_str_len: int = ...,
    max_bin_len: int = ...,
    max_array_len: int = ...,
    max_map_len: int = ...,
    max_ext_len: int = ...,
) -> Any: ...

load = unpack
loads = unpackb

dump = pack
dumps = packb

__all__ = [
    "BufferFull",
    "ExtType",
    "ExtraData",
    "FormatError",
    "OutOfData",
    "PackException",
    "PackOverflowError",
    "PackValueError",
    "Packer",
    "StackError",
    "Timestamp",
    "UnpackException",
    "UnpackValueError",
    "_version",
    "Unpacker",
    "dump",
    "dumps",
    "exceptions",
    "ext",
    "load",
    "loads",
    "pack",
    "packb",
    "unpack",
    "unpackb",
    "version",
]




from typing import Any

class UnpackException(Exception): ...
class BufferFull(UnpackException): ...
class OutOfData(UnpackException): ...
class FormatError(ValueError, UnpackException): ...
class StackError(ValueError, UnpackException): ...

UnpackValueError = ValueError

class ExtraData(UnpackValueError):
    def __init__(self, unpacked: Any, exta: Any) -> None: ...

PackException = Exception
PackValueError = ValueError
PackOverflowError = OverflowError



from __future__ import annotations
from typing import Any, Callable, Dict, List, Optional, Tuple

from typing_extensions import Protocol

class _FileLike(Protocol):
    def read(n: int) -> bytes: ...

def unpackb(
    packed: bytes,
    file_like: Optional[_FileLike] = ...,
    read_size: int = ...,
    use_list: bool = ...,
    raw: bool = ...,
    timestamp: int = ...,
    strict_map_key: bool = ...,
    object_hook: Optional[Callable[[Dict[Any, Any]], Any]] = ...,
    object_pairs_hook: Optional[Callable[[List[Tuple[Any, Any]]], Any]] = ...,
    list_hook: Optional[[Callable[[List[Any]], Any]]] = ...,
    unicode_errors: Optional[str] = ...,
    max_buffer_size: int = ...,
    ext_hook: Callable[[int, bytes], Any] = ...,
    max_str_len: int = ...,
    max_bin_len: int = ...,
    max_array_len: int = ...,
    max_map_len: int = ...,
    max_ext_len: int = ...,
) -> Any: ...

class Unpacker:
    def __init__(
        self,
        file_like: Optional[_FileLike] = ...,
        read_size: int = ...,
        use_list: bool = ...,
        raw: bool = ...,
        timestamp: int = ...,
        strict_map_key: bool = ...,
        object_hook: Optional[Callable[[Dict[Any, Any]], Any]] = ...,
        object_pairs_hook: Optional[Callable[[List[Tuple[Any, Any]]], Any]] = ...,
        list_hook: Optional[[Callable[[List[Any]], Any]]] = ...,
        unicode_errors: Optional[str] = ...,
        max_buffer_size: int = ...,
        ext_hook: Callable[[int, bytes], Any] = ...,
        max_str_len: int = ...,
        max_bin_len: int = ...,
        max_array_len: int = ...,
        max_map_len: int = ...,
        max_ext_len: int = ...,
    ): ...
    def feed(self, next_bytes: bytes) -> None: ...
    def read_bytes(self, n: int) -> bytearray: ...
    def __iter__(self) -> Unpacker: ...
    def __next__(self) -> Any: ...
    def next(self) -> Any: ...
    def skip(self) -> None: ...
    def unpack(self) -> Any: ...
    def read_array_header(self) -> Any: ...
    def read_map_header(self) -> Any: ...
    def tell(self) -> int: ...

class Packer:
    def __init__(
        self,
        default: Optional[Callable[[Any], Any]] = ...,
        use_single_float: bool = ...,
        autoreset: bool = ...,
        use_bin_type: bool = ...,
        strict_types: bool = ...,
        datetime: bool = ...,
        unicode_errors: Optional[str] = ...,
    ): ...
    def pack(self, obj: Any) -> bytes: ...
    def pack_map_pairs(self, pairs: Any) -> bytes: ...
    def pack_array_header(self, n: int) -> bytes: ...
    def pack_map_header(self, n: int) -> bytes: ...
    def pack_ext_type(self, typecode: int, data: bytes) -> None: ...
    def bytes(self) -> bytes: ...
    def reset(self) -> None: ...
    def getbuffer(self) -> memoryview: ...




from __future__ import annotations
from typing import NamedTuple
import datetime

class _ExtType(NamedTuple):
    code: int
    data: bytes

class ExtType(_ExtType): ...

class TimeStamp:
    def __init__(self, seconds: int, nanoseconds: int = ...) -> None: ...
    def __eq__(self, o: object) -> bool: ...
    def __ne__(self, o: object) -> bool: ...
    @staticmethod
    def from_bytes(b: bytes) -> TimeStamp: ...
    @staticmethod
    def to_bytes(self) -> bytes: ...
    @staticmethod
    def from_unix(self, unix_sec: float) -> TimeStamp: ...
    def to_unix(self) -> float: ...
    @staticmethod
    def from_unix_nano(unix_ns: int) -> TimeStamp: ...
    @staticmethod
    def to_unix_nano(self) -> int: ...
    def to_datetime(self) -> datetime.datetime: ...
    @staticmethod
    def from_datetime(dt: datetime.datetime) -> TimeStamp: ...




# -*- coding: utf-8 -*-
from distutils.core import setup

packages = \
['msgpack-stubs']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'msgpack-types',
    'version': '0.2.0',
    'description': 'Type stubs for msgpack',
    'long_description': '# msgpack-types [![PyPI](https://img.shields.io/pypi/v/msgpack-types.svg)](https://pypi.org/project/msgpack-types/)\n\n> Type stubs for [msgpack](https://github.com/msgpack/msgpack-python)\n\nAllows for autocomplete and static typing.\n\n## install\n\n```\npip install msgpack-types\n```\n\n## related\n\n- <https://github.com/sbdchd/django-types>\n- <https://github.com/sbdchd/djangorestframework-types>\n- <https://github.com/sbdchd/celery-types>\n- <https://github.com/sbdchd/mongo-types>\n',
    'author': 'Steve Dignam',
    'author_email': 'steve@dignam.xyz',
    'url': 'https://github.com/sbdchd/msgpack-types',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
